@@ -1,8 +1,8 @@
 from typing import Dict, Optional
 
 import pytorch_lightning as pl
-from pytorch_lightning.utilities.types import TRAIN_DATALOADERS, EVAL_DATALOADERS
 import torch
+from pytorch_lightning.utilities.types import EVAL_DATALOADERS, TRAIN_DATALOADERS
 
 from quaterion.train.cache import CacheEncoder
 
