@@ -2,7 +2,7 @@ from enum import Enum
 
 
 class TrainStage(str, Enum):
-    """Enum to handle train stage."""
+    """Handle train stage."""
 
     TRAIN = "train"
     VALIDATION = "validation"
